@@ -1,3 +1,4 @@
+import json
 import logging
 import re
 from typing import Dict, Iterable, Sequence
@@ -144,3 +145,41 @@ def dbt_diff_string_template(
         string_output += f"\n{k}: {v}"
 
     return string_output
+
+
+def _jsons_equiv(a: str, b: str):
+    try:
+        return json.loads(a) == json.loads(b)
+    except (ValueError, TypeError, json.decoder.JSONDecodeError):  # not valid jsons
+        return False
+
+
+def diffs_are_equiv_jsons(diff: list, json_cols: dict):
+    overriden_diff_cols = set()
+    if (len(diff) != 2) or ({diff[0][0], diff[1][0]} != {"+", "-"}):
+        return False, overriden_diff_cols
+    match = True
+    for i, (col_a, col_b) in enumerate(safezip(diff[0][1][1:], diff[1][1][1:])):  # index 0 is extra_columns first elem
+        # we only attempt to parse columns of JSON type, but we still need to check if non-json columns don't match
+        match = col_a == col_b
+        if not match and (i in json_cols):
+            if _jsons_equiv(col_a, col_b):
+                overriden_diff_cols.add(json_cols[i])
+                match = True
+        if not match:
+            break
+    return match, overriden_diff_cols
+
+
+def columns_removed_template(table2_set_diff) -> str:
+    columns_removed = "Column(s) removed: " + str(table2_set_diff) + "\n"
+    return columns_removed
+
+
+def columns_added_template(table1_set_diff) -> str:
+    columns_added = "Column(s) added: " + str(table1_set_diff) + "\n"
+    return columns_added
+
+
+def no_differences_template() -> str:
+    return "[bold][green]No row differences[/][/]\n"
